<?php

namespace Assetdocs\Department\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Department\Models\Department;

class DepartmentPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the department.
     *
     * @param User $user
     * @param Department $department
     *
     * @return bool
     */
    public function view(User $user, Department $department)
    {
        if ($user->canDo('department.department.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $department->user_id;
    }

    /**
     * Determine if the given user can create a department.
     *
     * @param User $user
     * @param Department $department
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('department.department.create');
    }

    /**
     * Determine if the given user can update the given department.
     *
     * @param User $user
     * @param Department $department
     *
     * @return bool
     */
    public function update(User $user, Department $department)
    {
        if ($user->canDo('department.department.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $department->user_id;
    }

    /**
     * Determine if the given user can delete the given department.
     *
     * @param User $user
     * @param Department $department
     *
     * @return bool
     */
    public function destroy(User $user, Department $department)
    {
        if ($user->canDo('department.department.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $department->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
